mix phoenix_kit.status (phoenix_kit v1.4.4)

Shows comprehensive status of PhoenixKit installation.

This task provides a detailed overview of your PhoenixKit installation status, including version information, database connectivity, assets status, and suggested next actions.

Usage

$ mix phoenix_kit.status
$ mix phoenix_kit.status --prefix=myapp

Options

  • --prefix - Database schema prefix (default: "public")
  • --verbose - Show detailed diagnostic information

Examples

# Show status for default installation
mix phoenix_kit.status

# Show status for custom schema prefix
mix phoenix_kit.status --prefix=auth

# Show detailed diagnostic information
mix phoenix_kit.status --verbose

Sample Output

PhoenixKit v1.2.1
 Installed: V03 
 Database: Connected 
 Assets: Built 
 Status: Ready to use