OTP Application module for PhoenixKit.
Note: PhoenixKit.Supervisor is started by the parent application, not by this module. This is an empty application callback.
OTP Application module for PhoenixKit.
Note: PhoenixKit.Supervisor is started by the parent application, not by this module. This is an empty application callback.