Table detail view with paginated row browsing.
Supports live updates via PostgreSQL LISTEN/NOTIFY - when data in the viewed table changes, the view refreshes automatically.
Summary
Functions
Callback implementation for Phoenix.LiveView.render/1.
Table detail view with paginated row browsing.
Supports live updates via PostgreSQL LISTEN/NOTIFY - when data in the viewed table changes, the view refreshes automatically.
Callback implementation for Phoenix.LiveView.render/1.