LiveView for creating and editing entity schemas. Provides form interface for defining entity fields, types, and validation rules.
Summary
Functions
Callback implementation for Phoenix.LiveView.render/1.
LiveView for creating and editing entity schemas. Provides form interface for defining entity fields, types, and validation rules.
Callback implementation for Phoenix.LiveView.render/1.