LiveView for the broadcasts list in the newsletters admin panel.
Summary
Functions
Callback implementation for Phoenix.LiveView.render/1.
Functions
Callback implementation for Phoenix.LiveView.render/1.
LiveView for the broadcasts list in the newsletters admin panel.
Callback implementation for Phoenix.LiveView.render/1.
Callback implementation for Phoenix.LiveView.render/1.