PhoenixKit.Modules.Publishing.Web.Editor.Preview (phoenix_kit v1.7.42)

Copy Markdown View Source

Preview functionality for the publishing editor.

Handles preview payload building, preview mode initialization, and preview-related state management.

Summary

Functions

Applies preview payload data to the socket.

Builds the preview payload from the current socket state.

Builds the preview URL query params.

Builds the editor path for preview mode.

Functions

apply_preview_payload(socket, data)

Applies preview payload data to the socket.

build_preview_payload(socket)

Builds the preview payload from the current socket state.

build_preview_query_params(preview_payload, token)

Builds the preview URL query params.

maybe_put_preview_new_flag(params, arg2)

maybe_put_preview_path(params, path)

preview_editor_path(socket, data, token, params)

Builds the editor path for preview mode.