PhoenixKit.Modules.Shop.Web.Plugs.ShopSession (phoenix_kit v1.7.69)

Copy Markdown View Source

Plug that ensures a persistent shop session ID exists.

This plug generates a unique session ID for guest users and stores it both in a dedicated cookie AND in the Phoenix session. This ensures the same cart is used across different pages.

Summary

Functions

call(conn, opts)

init(opts)