Product create/edit form LiveView for Shop module.
Includes dynamic option fields based on merged global + category schema, and displays option prices table for options that affect pricing.
Product create/edit form LiveView for Shop module.
Includes dynamic option fields based on merged global + category schema, and displays option prices table for options that affect pricing.