PhoenixKit.Modules.Storage.Workers.DeleteOrphanedFileJob (phoenix_kit v1.7.71)

Copy Markdown View Source

Oban job for deleting a single orphaned file.

Verifies the file is still orphaned before deletion to protect against race conditions where a file may be referenced again after being queued.