Oban worker that permanently deletes trashed files older than the configured retention period.
Runs daily via cron. Retention is configured via the trash_retention_days setting (default: 30).
Oban worker that permanently deletes trashed files older than the configured retention period.
Runs daily via cron. Retention is configured via the trash_retention_days setting (default: 30).