PhoenixKit.Modules.Tickets.Web.New (phoenix_kit v1.7.43)

Copy Markdown View Source

LiveView for creating new support tickets from admin panel.

Admins can create tickets on behalf of users with title, description, priority, and optional file attachments.

Summary

Functions

Callback implementation for Phoenix.LiveView.render/1.

Functions

render(assigns)

Callback implementation for Phoenix.LiveView.render/1.