PhoenixKit.Modules.Tickets.Web.UserNew (phoenix_kit v1.7.42)

Copy Markdown View Source

LiveView for creating new support tickets with file attachments.

Users can create tickets with title, description and drag-and-drop file uploads. Files are stored via Storage module and attached to the ticket after creation.

Summary

Functions

Callback implementation for Phoenix.LiveView.render/1.

Functions

render(assigns)

Callback implementation for Phoenix.LiveView.render/1.