PhoenixKit.RepoHelper (phoenix_kit v1.4.4)
View SourceHelper for dynamically resolving the repository to use.
This module provides functions to get the appropriate repository based on configuration. It will use the configured repo from the parent application if available, otherwise fall back to the built-in PhoenixKit.Repo for development/testing.
Summary
Functions
Delegates to the configured repo's aggregate function.
Delegates to the configured repo's all function.
Delegates to the configured repo's delete function.
Delegates to the configured repo's delete_all function.
Delegates to the configured repo's exists? function.
Delegates to the configured repo's get function.
Delegates to the configured repo's get! function.
Delegates to the configured repo's get_by function.
Delegates to the configured repo's insert function.
Delegates to the configured repo's insert! function.
Delegates to the configured repo's one function.
Delegates to the configured repo's preload function.
Delegates to the configured repo's query function.
Delegates to the configured repo's query! function.
Gets the repository module to use.
Delegates to the configured repo's rollback function.
Delegates to the configured repo's transaction function.
Delegates to the configured repo's update function.
Functions
Delegates to the configured repo's aggregate function.
Delegates to the configured repo's all function.
Delegates to the configured repo's delete function.
Delegates to the configured repo's delete_all function.
Delegates to the configured repo's exists? function.
Delegates to the configured repo's get function.
Delegates to the configured repo's get! function.
Delegates to the configured repo's get_by function.
Delegates to the configured repo's insert function.
Delegates to the configured repo's insert! function.
Delegates to the configured repo's one function.
Delegates to the configured repo's preload function.
Delegates to the configured repo's query function.
Delegates to the configured repo's query! function.
Gets the repository module to use.
Expects repo to be configured via PhoenixKit.Config.get(:repo). Raises an error if no repo is configured.
Delegates to the configured repo's rollback function.
This function is used within transactions to rollback and return an error value.
Delegates to the configured repo's transaction function.
Delegates to the configured repo's update function.