PhoenixKitWeb (phoenix_kit v1.7.33)

Copy Markdown View Source

The web interface for PhoenixKit.

This module provides the base functionality for web components including controllers, live views, and components used for user authentication and management.

Summary

Functions

__using__(which)

(macro)

When used, dispatch to the appropriate controller/view/etc.

channel()

controller()

core_components()

html()

live_component()

live_view()

router()

static_paths()

verified_routes()