PhoenixKitWeb.Components.Core.OrderStatusBadge (phoenix_kit v1.7.71)

Copy Markdown View Source

Provides order status badge components for the billing system.

Supports all order lifecycle statuses with appropriate color coding. Follows daisyUI badge styling conventions.

Summary

Functions

Renders an order status badge with appropriate styling.

Functions

order_status_badge(assigns)

Renders an order status badge with appropriate styling.

Attributes

  • status - Order status string (required)
  • size - Badge size: :xs, :sm, :md, :lg (default: :sm)
  • class - Additional CSS classes

Supported Statuses

  • draft - Order in draft state (ghost/gray)
  • pending - Order pending confirmation (warning/yellow)
  • confirmed - Order confirmed (info/blue)
  • paid - Order paid successfully (success/green)
  • cancelled - Order cancelled (error/red)
  • refunded - Order refunded (secondary/purple)

Examples

<.order_status_badge status="paid" />
<.order_status_badge status="pending" size={:md} />
<.order_status_badge status={@order.status} class="ml-2" />

Attributes

  • status (:string) (required)
  • size (:atom) - Defaults to :sm. Must be one of :xs, :sm, :md, or :lg.
  • class (:string) - Defaults to "".