PhoenixKitWeb.Layouts (phoenix_kit v1.6.16)

This module holds different layouts used by your application.

See the layouts directory for all templates available. The "root" layout is a skeleton rendered as part of the application router. The "app" layout is set as the default layout on both use PhoenixKitWeb, :controller and use PhoenixKitWeb, :live_view.

Summary

Functions

app(assigns)

root(assigns)