Settings LiveView for PhoenixKit Dashboard.
Allows authenticated users to update their email, password, profile information, and personal preferences such as timezone, date format, and time format.
Settings LiveView for PhoenixKit Dashboard.
Allows authenticated users to update their email, password, profile information, and personal preferences such as timezone, date format, and time format.