PhoenixKitWeb.Live.Settings.Organization (phoenix_kit v1.7.33)

Copy Markdown View Source

Organization settings management LiveView for PhoenixKit.

Provides a unified interface for company information shared between Legal and Billing modules. This includes company details and bank information.

Summary

Functions

Gets bank details from consolidated key with fallback to legacy keys.

Gets company info from consolidated key with fallback to legacy keys.

Callback implementation for Phoenix.LiveView.render/1.

Functions

get_bank_details()

Gets bank details from consolidated key with fallback to legacy keys.

get_company_info()

Gets company info from consolidated key with fallback to legacy keys.

handle_event(binary, params, socket)

Callback implementation for Phoenix.LiveView.handle_event/3.

handle_info(arg, socket)

Callback implementation for Phoenix.LiveView.handle_info/2.

handle_params(params, url, socket)

Callback implementation for Phoenix.LiveView.handle_params/3.

mount(params, session, socket)

Callback implementation for Phoenix.LiveView.mount/3.

render(assigns)

Callback implementation for Phoenix.LiveView.render/1.