PhoenixKitWeb.Live.Settings.SEO (phoenix_kit v1.7.71)

Copy Markdown View Source

SEO settings management LiveView for PhoenixKit.

Provides a simple interface for global indexing directives (noindex/nofollow) to keep staging or development deployments out of search engines.

Summary

Functions

handle_event(binary, params, socket)

Callback implementation for Phoenix.LiveView.handle_event/3.

mount(params, session, socket)

Callback implementation for Phoenix.LiveView.mount/3.

render(assigns)

Callback implementation for Phoenix.LiveView.render/1.