PhoenixKitWeb.Live.Users.Media (phoenix_kit v1.7.98)

Copy Markdown View Source

Media management LiveView — thin wrapper around MediaBrowser LiveComponent.

This LiveView owns the page layout and assigns required by LayoutWrapper.app_layout. All media browser state and logic live in PhoenixKitWeb.Components.MediaBrowser.

Summary

Functions

handle_info(arg, socket)

Callback implementation for Phoenix.LiveView.handle_info/2.

handle_params(params, uri, socket)

Callback implementation for Phoenix.LiveView.handle_params/3.

mount(params, session, socket)

Callback implementation for Phoenix.LiveView.mount/3.

render(assigns)

Callback implementation for Phoenix.LiveView.render/1.