Email module routes.
Provides route definitions for email webhooks, exports, and admin interfaces. Separated to improve compilation time.
Summary
Functions
Returns quoted admin LiveView route declarations for inclusion in the shared admin live_session.
Returns quoted code for email non-LiveView routes (webhooks, exports).