Endpoint integration for PhoenixKit installation.
Previously, this module added the phoenix_kit_socket() macro to the parent app's
endpoint. This is no longer needed as the Sync websocket is now handled automatically
via phoenix_kit_routes() in the router.
This module now removes any existing deprecated phoenix_kit_socket() calls from
endpoints during installation/updates.
Summary
Functions
Removes deprecated phoenix_kit_socket() and its import from the endpoint.
Functions
Removes deprecated phoenix_kit_socket() and its import from the endpoint.
The phoenix_kit_socket() macro is deprecated. Sync websocket is now handled
automatically via phoenix_kit_routes() in the router.
Parameters
igniter- The igniter context
Returns
Updated igniter with deprecated socket code and import removed.