V57: UUID FK Column Repair
Re-runs the idempotent UUID FK column operations from V56 to catch any columns that were missed when V56 was applied with an earlier version of the UUIDFKColumns module.
Specifically fixes phoenix_kit_role_permissions which may be missing
role_uuid and granted_by_uuid columns if V56 was applied before
those entries were added to UUIDFKColumns.
All operations are idempotent — this is a safe no-op on databases where V56 already created everything correctly.