Printable credit note view - displays refund/credit note in a print-friendly format.
This page is designed to be printed or saved as PDF directly from the browser. Credit notes are generated for refund transactions.
IMPORTANT: In a credit note, the roles are reversed compared to invoice:
- The company (seller) is now the PAYER (issuing the refund)
- The customer is now the PAYEE (receiving the refund)
Summary
Functions
Callback implementation for Phoenix.LiveView.render/1.
Functions
Callback implementation for Phoenix.LiveView.render/1.