Invoice detail LiveView for the billing module.
Displays complete invoice information and provides actions for invoice management.
Complex business logic is delegated to Actions, and template helpers live in Helpers.
Summary
Functions
Callback implementation for Phoenix.LiveView.render/1.
Functions
Callback implementation for Phoenix.LiveView.render/1.