Shared helper functions for the publishing editor.
Contains utilities for URL building, language handling, virtual post creation, and other common operations.
Summary
Functions
Assigns current language with enabled/known status.
Builds language data for the publishing_language_switcher component.
Builds the public URL for a post.
Builds a virtual post for new post creation.
Builds a virtual translation for a new language.
Gets the editor language from assigns.
Gets the preview URL for a featured image.
Formats a list of language codes for display.
Gets the URL for a file from storage.
Gets the language name for a language code.
Gets post directory path for primary language status check.
Sanitizes a featured image ID value.
Gets the base directory for a slug-mode post.
Functions
Assigns current language with enabled/known status.
Builds language data for the publishing_language_switcher component.
Builds the public URL for a post.
Builds a virtual post for new post creation.
Builds a virtual translation for a new language.
Gets the editor language from assigns.
Gets the preview URL for a featured image.
Formats a list of language codes for display.
Gets the URL for a file from storage.
Gets the language name for a language code.
Gets post directory path for primary language status check.
Sanitizes a featured image ID value.
Gets the base directory for a slug-mode post.