Preview functionality for the publishing editor.
Handles preview payload building, preview mode initialization, and preview-related state management.
Summary
Functions
Applies preview payload data to the socket.
Builds the preview payload from the current socket state.
Builds the preview URL query params.
Builds the editor path for preview mode.
Functions
Applies preview payload data to the socket.
Builds the preview payload from the current socket state.
Builds the preview URL query params.
Builds the editor path for preview mode.