Public cart page LiveView for E-Commerce module.
Supports real-time cart synchronization across multiple browser tabs via PubSub subscription. When cart is updated in one tab, all other tabs receive the update automatically.
Public cart page LiveView for E-Commerce module.
Supports real-time cart synchronization across multiple browser tabs via PubSub subscription. When cart is updated in one tab, all other tabs receive the update automatically.