LiveView for displaying order details to the order owner.
Users can view their own orders with full details including:
- Order items and totals
- Billing information
- Order status
Security:
- Users can only view their own orders (user_id check)
Summary
Functions
Callback implementation for Phoenix.LiveView.render/1.
Functions
Callback implementation for Phoenix.LiveView.render/1.