LiveView for creating new support tickets from admin panel.
Admins can create tickets on behalf of users with title, description, priority, and optional file attachments.
Summary
Functions
Callback implementation for Phoenix.LiveView.render/1.
Functions
Callback implementation for Phoenix.LiveView.render/1.