LiveView for creating new support tickets with file attachments.
Users can create tickets with title, description and drag-and-drop file uploads. Files are stored via Storage module and attached to the ticket after creation.
Summary
Functions
Callback implementation for Phoenix.LiveView.render/1.
Functions
Callback implementation for Phoenix.LiveView.render/1.