The web interface for PhoenixKit.
This module provides the base functionality for web components including controllers, live views, and components used for user authentication and management.
Summary
Functions
When used, dispatch to the appropriate controller/view/etc.