Organization settings management LiveView for PhoenixKit.
Provides a unified interface for company information shared between Legal and Billing modules. This includes company details and bank information.
Summary
Functions
Gets bank details from consolidated key with fallback to legacy keys.
Gets company info from consolidated key with fallback to legacy keys.
Callback implementation for Phoenix.LiveView.handle_event/3.
Callback implementation for Phoenix.LiveView.handle_info/2.
Callback implementation for Phoenix.LiveView.handle_params/3.
Callback implementation for Phoenix.LiveView.mount/3.
Callback implementation for Phoenix.LiveView.render/1.
Functions
Gets bank details from consolidated key with fallback to legacy keys.
Gets company info from consolidated key with fallback to legacy keys.
Callback implementation for Phoenix.LiveView.handle_event/3.
Callback implementation for Phoenix.LiveView.handle_info/2.
Callback implementation for Phoenix.LiveView.handle_params/3.
Callback implementation for Phoenix.LiveView.mount/3.
Callback implementation for Phoenix.LiveView.render/1.