SEO settings management LiveView for PhoenixKit.
Provides a simple interface for global indexing directives (noindex/nofollow) to keep staging or development deployments out of search engines.
Summary
Functions
Callback implementation for Phoenix.LiveView.handle_event/3.
Callback implementation for Phoenix.LiveView.mount/3.
Callback implementation for Phoenix.LiveView.render/1.
Functions
Callback implementation for Phoenix.LiveView.handle_event/3.
Callback implementation for Phoenix.LiveView.mount/3.
Callback implementation for Phoenix.LiveView.render/1.